/*
* ldigest.c
* message digest library for Lua based on OpenSSL or Apple CommonDigest
* Luiz Henrique de Figueiredo <lhf@tecgraf.puc-rio.br>
* 24 Jul 2018 11:16:26
* This code is hereby placed in the public domain and also under the MIT license
*/

#ifdef __APPLE__
#define COMMON_DIGEST_FOR_OPENSSL
#include <CommonCrypto/CommonDigest.h>
#define AUTHOR		"Apple CommonDigest"
#endif

#ifdef __linux__
#include <openssl/opensslv.h>
#include <openssl/md4.h>
#include <openssl/md5.h>
#include <openssl/sha.h>
#define AUTHOR		OPENSSL_VERSION_TEXT
#endif

#include "lua.h"
#include "lauxlib.h"
#include "mycompat.h"

#define MYNAME		"digest"
#define MYVERSION	MYNAME " library for " LUA_VERSION " / Jul 2018 / "\
			"using " AUTHOR

#define SHA1_CTX		SHA_CTX
#define SHA1_DIGEST_LENGTH	SHA_DIGEST_LENGTH
#define SHA224_CTX		SHA256_CTX
#define SHA384_CTX		SHA512_CTX

#ifdef __APPLE__
#define DIGEST	MD2
#include "template.c"
#endif
#define DIGEST	MD4
#include "template.c"
#define DIGEST	MD5
#include "template.c"
#define DIGEST	SHA1
#include "template.c"
#define DIGEST	SHA224
#include "template.c"
#define DIGEST	SHA256
#include "template.c"
#define DIGEST	SHA384
#include "template.c"
#define DIGEST	SHA512
#include "template.c"

LUALIB_API int luaopen_digest(lua_State *L)
{
 lua_newtable(L);
 lua_pushliteral(L,"version");
 lua_pushliteral(L,MYVERSION);
 lua_settable(L,-3);
#ifdef __APPLE__
 populate_MD2(L,"md2");
#endif
 populate_MD4(L,"md4");
 populate_MD5(L,"md5");
 populate_SHA1(L,"sha1");
 populate_SHA224(L,"sha224");
 populate_SHA256(L,"sha256");
 populate_SHA384(L,"sha384");
 populate_SHA512(L,"sha512");
 return 1;
}
